function botGroup()
{
	if ( isObject( %obj = nameToID( "botGroup" ) ) )
	{
		return %obj;
	}

	return new scriptGroup( "botGroup" );
}

package botPackage
{
	function gameConnection::onDeath( %this, %killerPlayer, %killerClient, %damageType, %damageLoc )
	{
		if ( isObject( %killerClient ) && %killerClient.isAIControlled() )
		{
			messageAll( 'MsgClientKilled', $DeathMessage_Murder[ %damageType ], %this.name, %killerClient.name );
			
			%damageType = 0;
			%this.player.lastDirectDamageType = 0;
		}
		
		parent::onDeath( %this, %killerPlayer, %killerClient, %damageType, %damageLoc );
	}

	function AIConnection::onDeath( %this, %killerPlayer, %killerClient, %damageType, %damageLoc )
	{
		aiGroup().pop( %this.player );
		%this.player = "";
		
		%msg = $DeathMessage_Murder[ %damageType ];
		%typ = 'MsgClientKilled';
		
		if ( !isObject( %killerClient ) || %killerClient $= %this )
		{
			%msg = $DeathMessage_Suicide[ %damageType ];
			%typ = '';
		}
		
		messageAll( %typ, %msg, %this.name, %killerClient.name );
		%this.schedule( getRespawnTime(), "spawnPlayer" );
	}

	function AIConnection::getSpawnPoint( %this )
	{
		return getSpawnPoint( %this );
	}

	function AIConnection::createPlayer( %this, %transform )
	{
		if ( isObject( %miniGame = %this.miniGame ) )
		{
			%dataBlock = %miniGame.playerDataBlock;
		}
		else
		{
			%dataBlock = playerStandardArmor;
		}
		
		%obj = new AIPlayer()
		{
			dataBlock = %dataBlock;
			client = %this;
		};
		
		%obj.setTransform( %transform );
		missionCleanup.add( %obj );
		
		%obj.clearTools();
		
		if ( isObject( %miniGame ) )
		{
			for ( %i = 0 ; %i < %dataBlock.maxTools ; %i++ )
			{
				%obj.tool[ %i ] = %miniGame.startEquip[ %i ];
			}
		}
		else
		{
			%obj.giveDefaultEquipment();
		}
		
		%this.player = %obj;
		%this.applyBodyParts();
		%this.applyBodyColors();

		aiGroup().push( %obj );
		return %obj;
	}
};

activatePackage( "botPackage" );

function addBot()
{
	if ( !isObject( %group = botGroup() ) )
	{
		return -1;
	}

	%obj = new AIConnection()
	{
		name = "Bot " @ %group.getCount();
		bl_id = -1;
		hasSpawnedOnce = true;
	};

	%group.add( %obj );
	%obj.schedule( 0, "spawnPlayer" );

	return %obj;
}

function AIConnection::botRemove( %this )
{
	if ( isObject( %pl = %this.player ) )
	{
		%pl.delete();
	}

	%this.delete();
}

function AIConnection::getPlayerName( %this )
{
	return %this.name;
}

function AIPlayer::getPlayerName( %this )
{
	return %this.client.name;
}

function kickBots()
{
	while ( botGroup().getCount() )
	{
		botGroup().getObject( 0 ).botRemove();
	}
}