$AI::Rate = 24;
$AI::Quota = 8;

exec( "./support.cs" );
exec( "./pathfind.cs" );

exec( "./manager.cs" );
exec( "./ai.cs" );

exec( "./vision.cs" );
exec( "./sound.cs" );
exec( "./calls.cs" );
exec( "./behavior.cs" );

package bot_package
{
	function gameConnection::onDeath( %this, %killerPlayer, %killerClient, %damageType, %damageLoc )
	{
		if ( isObject( %killerClient ) && %killerClient.isAIControlled() )
		{
			messageAll( 'MsgClientKilled', $DeathMessage_Murder[ %damageType ], %this.name, %killerClient.name );
			
			%damageType = 0;
			%this.player.lastDirectDamageType = 0;
		}
		
		parent::onDeath( %this, %killerPlayer, %killerClient, %damageType, %damageLoc );
	}

	function AIConnection::onDeath( %this, %killerPlayer, %killerClient, %damageType, %damageLoc )
	{
		if ( isObject( %this.player.visionSet ) )
		{
			%this.player.visionSet.delete();
		}

		AIGroup.pop( %this.player );
		%this.player = "";
		
		%msg = $DeathMessage_Murder[ %damageType ];
		
		if ( !isObject( %killerClient ) || %killerClient $= %this )
		{
			%msg = $DeathMessage_Suicide[ %damageType ];
		}
		
		messageAll( 'MsgClientKilled', %msg, %this.name, %killerClient.name );
		%this.schedule( 3000, "spawnPlayer" );
	}

	function AIConnection::getSpawnPoint( %this )
	{
		return pickSpawnPoint();
	}

	function AIConnection::createPlayer( %this, %transform )
	{
		if ( isObject( %miniGame = %this.miniGame ) )
		{
			%dataBlock = %miniGame.playerDataBlock;
		}
		else
		{
			%dataBlock = playerStandardArmor;
		}
		
		%obj = new AIPlayer()
		{
			dataBlock = %dataBlock;
			client = %this;
			state = "idle";
			behavior = -1;

			visionRange = 512;
			visionFOV = 90;
		};
		
		%obj.setTransform( %transform );
		missionCleanup.add( %obj );

		%obj.visionSet = new simSet();
		%obj.clearTools();
		
		if ( isObject( %miniGame ) )
		{
			for ( %i = 0 ; %i < %dataBlock.maxTools ; %i++ )
			{
				%obj.tool[ %i ] = %miniGame.startEquip[ %i ];
			}
		}
		else
		{
			%obj.giveDefaultEquipment();
		}
		
		%this.player = %obj;
		%this.applyBodyParts();
		%this.applyBodyColors();

		AIGroup.push( %obj );
		return %obj;
	}

	function AIPlayer::onRemove( %this )
	{
		if ( isObject( %this.visionSet ) )
		{
			%this.visionSet.delete();
		}

		parent::onRemove( %this );
	}
};

activatePackage( "bot_package" );